#include <pi-calendar.h>
#include "../jpilot_src/libplugin.h"
#include "pytype_basics.h"

extern PyObject* PyPiEvent_New();

extern PyObject* PyPiEvent_Wrap(CalendarEvent_t*, PCRecType, unsigned int, unsigned char,
				 int, void*, PyObject *);

extern PyTypeObject EventType;

#define PyPiEvent_Check(v)          PyObject_TypeCheck(v, &EventType)
#define PyPiEvent_CheckExact(v)     ((v)->ob_type == &EventType)

typedef struct {
  PyObject_HEAD
  PyObject_JPTYPE
  CalendarEvent_t a;
} PyPiEvent;
